# GlobalStep

This section contains the API reference for the [`GlobalStep`][distilabel.steps.base.GlobalStep] class.

For more information and examples on how to use existing global steps or create custom ones, please refer to [Tutorial - Step - GlobalStep](../../sections/how_to_guides/basic/step/global_step.md).

::: distilabel.steps.base.GlobalStep
